summaryrefslogtreecommitdiff
path: root/geneticone.py
diff options
context:
space:
mode:
authornecoro <>2006-11-24 11:49:51 +0000
committernecoro <>2006-11-24 11:49:51 +0000
commit10c8bd3678f1a13e9ff4dc59b7907c4a7726d67e (patch)
treec8172c4f12be5a9019b3f06afc71ffbf9db4c046 /geneticone.py
parent38a7fdbeff355e5df5c6552306a23d46074e3e0a (diff)
downloadportato-10c8bd3678f1a13e9ff4dc59b7907c4a7726d67e.tar.gz
portato-10c8bd3678f1a13e9ff4dc59b7907c4a7726d67e.tar.bz2
portato-10c8bd3678f1a13e9ff4dc59b7907c4a7726d67e.zip
Renamed to portato
Diffstat (limited to '')
-rwxr-xr-xgeneticone.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/geneticone.py b/geneticone.py
index 9abefd3..1c60e5f 100755
--- a/geneticone.py
+++ b/geneticone.py
@@ -2,8 +2,8 @@
# -*- coding: utf-8 -*-
#
# File: geneticone.py
# This file is part of the Genetic/One-Project, a graphical portage-frontend.
#
# Copyright (C) 2006 René 'Necoro' Neumann
# This is free software. You may redistribute copies of it under the terms of
@@ -12,12 +12,12 @@
#
# Written by René 'Necoro' Neumann <necoro@necoro.net>
-from geneticone.constants import VERSION
+from portato.constants import VERSION
import sys
if __name__ == "__main__":
if len(sys.argv) > 1 and sys.argv[1] in ("--help","--version","-h","-v"):
- print """Genetic/One %s
+ print """Portato %s
Copyright (C) 2006 René 'Necoro' Neumann
This is free software. You may redistribute copies of it under the terms of
the GNU General Public License <http://www.gnu.org/licenses/gpl.html>.
@@ -25,6 +25,6 @@ There is NO WARRANTY, to the extent permitted by law.
Written by René 'Necoro' Neumann <necoro@necoro.net>""" % VERSION
else:
- from geneticone.gui import MainWindow
+ from portato.gui import MainWindow
m = MainWindow()
m.main()
@@ -2,8 +2,8 @@
# -*- coding: utf-8 -*-
#
-# File: geneticone.py
-# This file is part of the Genetic/One-Project, a graphical portage-frontend.
+# File: portato.py
+# This file is part of the Portato-Project, a graphical portage-frontend.
#
# Copyright (C) 2006 René 'Necoro' Neumann